"use client";

import React, { useEffect, useState } from 'react';
import Link from 'next/link';
import { FaPlus, FaPlay, FaList, FaCheck } from 'react-icons/fa';
import { generateSlug } from "@/lib/generateSlug";
import { motion } from 'framer-motion';

const HeroMobile: React.FC = () => {
  const [trending, setTrending] = useState<any>(null);
  const [isInList, setIsInList] = useState(false);
  const [notification, setNotification] = useState<string | null>(null);

  useEffect(() => {
    const fetchTrending = async () => {
      try {
        const response = await fetch(
          `https://api.themoviedb.org/3/trending/all/day?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
        );
        const data = await response.json();
        const randomIndex = Math.floor(Math.random() * data.results.length);
        setTrending(data.results[randomIndex]);
      } catch (error) {
        console.error('Failed to fetch trending data:', error);
      }
    };

    fetchTrending();
  }, []);

  useEffect(() => {
    if (trending) {
      const storedList = JSON.parse(localStorage.getItem('myList') || '[]');
      setIsInList(storedList.some((item: { id: number, media_type: string }) => item.id === trending.id && item.media_type === trending.media_type));
    }
  }, [trending]);

  if (!trending) {
    return <div>Loading...</div>; // You can add a loading animation here
  }

  const backgroundImage = `https://image.tmdb.org/t/p/original${trending.backdrop_path}`;
  const title = trending.title || trending.name || "Untitled";

  // Generate the slug using the movie ID and title
  const slug = generateSlug(title, trending.id);
  const mediaType = trending.media_type === 'movie' ? 'movie' : 'tv';

  const handleAddOrRemoveFromList = () => {
    const storedList = JSON.parse(localStorage.getItem('myList') || '[]');
    const itemExists = storedList.some((item: { id: number, media_type: string }) => item.id === trending.id && item.media_type === trending.media_type);

    if (itemExists) {
      const updatedList = storedList.filter((item: { id: number, media_type: string }) => !(item.id === trending.id && item.media_type === trending.media_type));
      localStorage.setItem('myList', JSON.stringify(updatedList));
      setIsInList(false);
      setNotification(`${title} removed from your list`);
    } else {
      storedList.push({ id: trending.id, media_type: trending.media_type });
      localStorage.setItem('myList', JSON.stringify(storedList));
      setIsInList(true);
      setNotification(`${title} added to your list`);
    }

    setTimeout(() => setNotification(null), 2000);
  };

  return (
    <div
      className="relative h-[60vh] bg-cover bg-center"
      style={{ backgroundImage: `url(${backgroundImage})` }}
    >
      <div className="absolute inset-0 flex flex-col items-center justify-end pb-12 text-center">
        <div className="absolute inset-0 bg-gradient-to-t from-black to-transparent"></div>
        <h1 className="text-2xl text-white font-bold mb-4 animate-slideInDown z-10">
          {title}
        </h1>
        <div className="flex space-x-3 animate-slideInUp z-10">
          <button
            className={`px-3 py-2 ${isInList ? 'bg-green-600' : 'bg-white/20 hover:bg-white/30'} text-white rounded-lg flex items-center transition-transform transform hover:scale-105 shadow-lg`}
            onClick={handleAddOrRemoveFromList}
          >
            {isInList ? (
              <>
                <FaCheck className="mr-1" /> Added
              </>
            ) : (
              <>
                <FaPlus className="mr-1" /> Add List
              </>
            )}
          </button>
          <Link href={`/watch/${mediaType}?slug=${slug}`} passHref>
            <button className="px-3 py-2 backdrop-blur-md bg-white/20 hover:bg-white/30 text-white rounded-lg flex items-center transition-transform transform hover:scale-105 shadow-lg">
              <FaPlay className="mr-1" /> Play
            </button>
          </Link>
          <Link href="/mylist" passHref>
            <button className="px-3 py-2 backdrop-blur-md bg-white/20 hover:bg-white/30 text-white rounded-lg flex items-center transition-transform transform hover:scale-105 shadow-lg">
              <FaList className="mr-1" /> My List
            </button>
          </Link>
        </div>
      </div>

      {/* Notification for adding/removing from the list */}
      {notification && (
        <motion.div
          className="fixed bottom-20 left-1/2 transform -translate-x-1/2 bg-green-600 text-white py-2 px-4 rounded-lg shadow-lg z-50 flex items-center space-x-2"
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          exit={{ opacity: 0, y: 20 }}
          transition={{ duration: 0.5 }}
        >
          <FaCheck />
          <span>{notification}</span>
        </motion.div>
      )}
    </div>
  );
};

export default HeroMobile;
